@@ -23,6 +23,7 @@ from .descriptor_props import ComparableProperty  # noqa
 from .descriptor_props import CompositeProperty  # noqa
 from .descriptor_props import SynonymProperty  # noqa
 from .interfaces import EXT_CONTINUE  # noqa
+from .interfaces import EXT_SKIP  # noqa
 from .interfaces import EXT_STOP  # noqa
 from .interfaces import PropComparator  # noqa
 from .mapper import _mapper_registry
@@ -39,6 +40,7 @@ from .relationships import foreign  # noqa
 from .relationships import RelationshipProperty  # noqa
 from .relationships import remote  # noqa
 from .scoping import scoped_session  # noqa
+from .session import close_all_sessions  # noqa
 from .session import make_transient  # noqa
 from .session import make_transient_to_detached  # noqa
 from .session import object_session  # noqa
@@ -192,8 +194,8 @@ comparable_property = public_factory(
 
 @_sa_util.deprecated(
     "0.7",
-    message=":func:`.compile_mappers` "
-    "is renamed to :func:`.configure_mappers`",
+    message=":func:`.compile_mappers` is deprecated and will be removed "
+    "in a future release.  Please use :func:`.configure_mappers`",
 )
 def compile_mappers():
     """Initialize the inter-mapper relationships of all mappers that have
